#
# spec file for package gcin
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _distconfdir}
%define _distconfdir %{_sysconfdir}
%endif

%define build_qt4 0%{?is_opensuse} && 0%{?suse_version} < 1550 && 0%{?sle_version} < 150300

Name:           gcin
Version:        2.9.0
Release:        bp155.3.19
Summary:        Chinese input method server
License:        LGPL-2.1-only
Group:          System/I18n/Chinese
URL:            http://hyperrate.com/dir.php?eid=67
Source:         http://hyperrate.com/gcin-source/%{name}-%{version}.tar.xz
Source1:        xim.d-gcin
Source2:        gcin-README.suse
Source3:        xim.gcin.suse.template
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM glin@suse.com - just install the _only_ icon to pixmaps
Patch1:         icon_path.diff
# PATCH-FIX-UPSTREAM swyear@opensuse.org - fix qt3 detection in configure
Patch2:         gcin-libdir.patch
# PATCH-FIX-UPSTREAM marguerite@opensuse.org - fix gtk2/3 immodules install path
Patch3:         gcin-2.8.1-gtk_immodules_path.patch
# PATCH-FIX-UPSTREAM swyear@opensuse.org - fix doc path (used to open doc from gcin-tools)
Patch4:         doc_dir.diff
# PATCH-FIX-UPSTREAM glin@suse.com - keep the debug symbols
Patch5:         gcin-keep-debug-symbols.patch
# PATCH-FIX-UPSTREAM glin@suse.com - fix the Makefile dependency for parallel compiling
Patch7:         gcin-parallel-compiling.patch
# PATCH-FIX-OPENSUSE mlin@suse.com - improve build with pkgconfig and add private headers at moc period
Patch8:         gcin-improve-build-with-pkgconfig.patch
# PATCH-FIX-UPSTREAM boo#951750 glin@suse.com - fix the qt5 iid
Patch9:         gcin-fix-qt5-iid.patch
# PATCH-FIX-OPENSUSE glin@suse.com - Don't copy gcin-qt5.h.in since we already patched gcin-qt5.h
Patch10:        gcin-dont-copy-gcin-qt5-header.patch
# PATCH-FIX-UPSTREAM gcin-remove-dead-code.patch - remove the dead code to avoid the warning
Patch11:        gcin-remove-dead-code.patch
BuildRequires:  anthy-devel
BuildRequires:  fdupes
BuildRequires:  gtk2-devel
BuildRequires:  gtk3-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5PlatformSupport-devel-static
BuildRequires:  libXtst-devel
BuildRequires:  libcurl-devel
BuildRequires:  libjpeg-devel
%if %{build_qt4}
BuildRequires:  libqt4-devel
%endif
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
BuildRequires:  xz
Requires:       %{name}-branding
Requires:       %{name}-gtk2 = %{version}
Requires:       %{name}-gtk3 = %{version}
%if %{build_qt4}
Requires:       %{name}-qt4 = %{version}
%endif
Requires:       %{name}-qt5 = %{version}
Requires:       libgcin-im-client1 = %{version}
Recommends:     libreoffice-gnome
Provides:       locale(zh_TW;zh_HK;zh_MO)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
gcin is a Chinese input method server for traditional Chinese.
It features a better GTK user interface.

%package branding-upstream
Summary:        Upstream branding of gcin
License:        LGPL-2.1-only
Group:          System/I18n/Chinese
Requires:       gcin = %{version}
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}

%description branding-upstream
This package provides upstream look and feel for gcin

%package -n libgcin-im-client1
Summary:        Share libraries of gcin
License:        LGPL-2.1-only
Group:          System/Libraries

%description -n libgcin-im-client1
This package provides runtime libraries for gcin.

%package gtk2
Summary:        Gcin gtk2 immodule
License:        LGPL-2.1-only
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Provides:       %{name}-gtk2-immodule = %{version}
Obsoletes:      %{name}-gtk2-immodule <= 2.8.4-77.16
%{gtk2_immodule_requires}

%description gtk2
gcin gtk2 immodule, support gtk2-based applications

%if %{build_qt4}
%package qt4
Summary:        Gcin qt4 immodule
License:        GPL-2.0-only
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Provides:       %{name}-qt4-immodule = %{version}
Obsoletes:      %{name}-qt4-immodule <= 2.8.4-77.16

%description qt4
gcin qt4 immodule, support Qt4-based applications
%endif

%package qt5
Summary:        Gcin qt5 immodule
License:        GPL-2.0-only
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Provides:       %{name}-qt5-immodule = %{version}
Obsoletes:      %{name}-qt5-immodule <= 2.8.4-77.16

%description qt5
gcin qt5 immodule, support Qt5-based applications

%package anthy
Summary:        Gcin anthy module
License:        LGPL-2.1-only
Group:          System/I18n/Japanese
Requires:       %{name} = %{version}
Provides:       %{name}-anthy-module = %{version}
Obsoletes:      %{name}-anthy-module <= 2.8.4-77.16

%description anthy
gcin anthy module, try this to input Japanese with libanthy

%package gtk3
Summary:        Gcin gtk3 immodule
License:        LGPL-2.1-only
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Provides:       %{name}-gtk3-immodule = %{version}
Obsoletes:      %{name}-gtk3-immodule <= 2.8.4-77.16
%{gtk3_immodule_requires}

%description gtk3
gcin gtk3 immodule, support gtk3-based applications

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
cp -r %{SOURCE2} .
cp -r %{SOURCE3} .

# scripts/modify-XIM is mainly for Fedora/Mandriva and Qt3, obsoleted
rm -rf scripts/modify-XIM
sed -i "s/modify-XIM//" scripts/Makefile

%build
%if "%{_lib}" == "lib64"
sed -e "s,^LIB='lib',LIB=lib64," -i configure
%endif
CFLAGS="%{optflags}" %configure --prefix=/usr --use_i18n=Y \
--use_anthy=Y --doc_version_dir=N

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

mkdir -p %{buildroot}%{_distconfdir}/X11/xim.d/
install -m 644 %{SOURCE1} %{buildroot}%{_distconfdir}/X11/xim.d/gcin

rm -rf %{buildroot}%{_datadir}/doc

%suse_update_desktop_file -r -G "Set Up your inputmethod" gcin-tools Settings System SystemSetup

PRIORITY=30
pushd  %{buildroot}%{_distconfdir}/X11/xim.d/
    for lang in en zh_TW zh_HK zh_MO ; do
        mkdir $lang
  pushd $lang
            ln -s ../gcin $PRIORITY-gcin
  popd
    done
popd

%find_lang %{name}
%fdupes %{buildroot}

%post -n libgcin-im-client1 -p /sbin/ldconfig

%postun -n libgcin-im-client1 -p /sbin/ldconfig

%post anthy -p /sbin/ldconfig

%postun anthy -p /sbin/ldconfig

%post gtk2
/sbin/ldconfig
%{gtk2_immodule_post}

%postun gtk2
/sbin/ldconfig
%{gtk2_immodule_postun}

%post gtk3
/sbin/ldconfig
#Add icons to gnome3 panel
TARGET="%{_datadir}/gnome-shell/js/ui/statusIconDispatcher.js"
if [ -f $TARGET ] ; then
 if [ -z "`grep gcin $TARGET`" ] ; then
   mv $TARGET $TARGET-gcin
   # add gcin string to the file
   sed "/^const STANDARD_TRAY_ICON_IMPLEMENTATIONS/a \    'gcin': 'input-method'," $TARGET-gcin > $TARGET
 fi
fi

%{gtk3_immodule_post}

%postun gtk3
/sbin/ldconfig
%{gtk3_immodule_postun}

%if %{build_qt4}
%post qt4 -p /sbin/ldconfig
%postun qt4 -p /sbin/ldconfig
%endif
%post qt5 -p /sbin/ldconfig
%postun qt5 -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root)
%license COPYING
%doc README.html Changelog.html AUTHORS gcin-README.suse xim.gcin.suse.template
%{_distconfdir}/X11/xim.d
%{_bindir}/*
%{_datadir}/gcin/
%{_datadir}/pixmaps/gcin.png
%{_datadir}/applications/*
%dir %{_datadir}/icons/gcin/

%files -n libgcin-im-client1
%defattr(-,root,root)
%dir %{_libdir}/gcin
%{_libdir}/gcin/libgcin-im-client.so
%{_libdir}/gcin/libgcin-im-client.so.1
%{_libdir}/gcin/libgcin-im-client.so.1.2.5
%{_libdir}/gcin/gcin1.so
%{_libdir}/gcin/gcin2.so
%{_libdir}/gcin/intcode-module.so

%files branding-upstream
%defattr(-,root,root)
%{_datadir}/icons/gcin/*

%files gtk2
%defattr(-,root,root)
%{_libdir}/gtk-2.0/2.10.0/immodules/im-gcin.so

%if %{build_qt4}
%files qt4
%defattr(-,root,root)
%{_libdir}/qt4/plugins/inputmethods/im-gcin.so
%endif

%files qt5
%defattr(-,root,root)
%{_libdir}/qt5/plugins/platforminputcontexts/libgcinplatforminputcontextplugin.so

%files anthy
%defattr(-,root,root)
%{_libdir}/gcin/anthy-module.so

%files gtk3
%defattr(-,root,root)
%{_libdir}/gtk-3.0/3.0.0/immodules/im-gcin.so

%changelog
* Tue Feb 23 2021 Gary Ching-Pang Lin <glin@suse.com>
- Fix the build failure due to the comparison of bare words
* Fri Dec  4 2020 Antonio Larrosa <alarrosa@suse.com>
- Do not build the qt4 subpackage for Leap 15.3 or newer
  (boo#1179613).
* Thu Nov 26 2020 tiwai@suse.de
- Move the startup snippet to /usr/etc/X11/xim.d for TW
* Mon Jun  8 2020 Gary Ching-Pang Lin <glin@suse.com>
- Update to 2.9.0
  + Fix gtab word choosing area mismatching
  + Fix an issue with hsu keyboard
  + gcc 10 compatibility
* Wed Apr 17 2019 tiwai@suse.de
- Drop build of gcin-qt4 subpackage on TW due to EOL of Qt4.
* Mon Apr  1 2019 Gary Ching-Pang Lin <glin@suse.com>
- Update to 2.8.9
  + Fix issues with gtk3 and switch to gtk3 by default
  + Fix an issue with 41 keys bopomofo
- Add gcin-remove-dead-code.patch to remove the dead code which
  causes the useless warning
* Thu Dec 27 2018 Gary Ching-Pang Lin <glin@suse.com>
- Update to 2.8.8
  + Fix a cursor issue in 26 keys bopomofo
  + Fix a issue with Hsu's keyboard layout and enabling
    "more UTF-8 characters"
- Refresh gcin-fix-qt5-iid.patch
- Use %%license for COPYING
* Fri May 25 2018 glin@suse.com
- Update to 2.8.6
  + Fixed a selection key problem with ctrl-alt-,
  + Use libcurl to upload/download phrases
  + Improved pinyin pre-select phrases
- Add libcurl-devel and libXtst-devel to BuildRequires
- Drop upstreamed patch: gcin-reproducible.patch
- Refresh patches
  + gcin-dont-copy-gcin-qt5-header.patch
  + gcin-improve-build-with-pkgconfig.patch
  + gcin-parallel-compiling.patch
- Remove the version check since openSUSE 13.1 is not supported
  long ago
- Only build gcin-qt4 for openSUSE
* Mon Sep  4 2017 bwiedemann@suse.com
- Add gcin-reproducible.patch to initialize memory
* Wed Jun 21 2017 glin@suse.com
- Amend gcin-improve-build-with-pkgconfig.patch for Qt 5.9.0
* Thu Mar  2 2017 glin@suse.com
- Add gcin-dont-copy-gcin-qt5-header.patch to avoid overwriting
  the patched gcin-qt5.h
* Thu Feb  9 2017 glin@suse.com
- Update to 2.8.5
  + Fix a typing bug with Hsu layout
  + Fix the missing pre-select phrases when using Array input
    method
- Refresh patches:
  + gcin-improve-build-with-pkgconfig.patch
  + gcin-parallel-compiling.patch
* Wed Oct 12 2016 glin@suse.com
- Amend baselibs.conf to avoid the immodules to require gcin-32bit
  (boo#1002566)
* Fri Sep  9 2016 glin@suse.com
- Remove libappindicator since KDE already brought system tray icon
  back.
* Wed Jun  8 2016 i@marguerite.su
- fix tumbleweed build
- refresh patch: gcin-improve-build-with-pkgconfig.patch
  * Qt5PlatformSupport has gone from Qt 5.6.0
  * fix include for qinputmethod.h
- add gcin-qt5 to baselibs.conf
- rename the sub-packages in openSUSE style
- split libgcin-im-client1 library
* Mon Oct 26 2015 mlin@suse.com
- Add gcin-improve-build-with-pkgconfig.patch
  + Improve build with pkgconfig
  + Add Qt5Gui private headers at moc period
- Update gcin-fix-qt5-iid.patch
  + Use macro instead of string literal, better backward compatibility
    for Qt5 < 5.5
* Sat Oct 24 2015 glin@suse.com
- Add gcin-fix-qt5-iid.patch to fix the qt5 iid so that the qt5
  applications can load the gcin immodule (boo#951750)
* Fri Oct 23 2015 glin@suse.com
- Update to 2.8.4
  + Switch to appindicator by default
  + Changes: http://hyperrate.com/gcin-source/Changelog.html
- Drop upstreamed fixes
  + qt5gui-header-path-fix.patch
  + plasma5-dirty-fix.patch
* Tue Sep 29 2015 ramaxlo@gmail.com
- Add gcin-qt5-immodule, libappindicator3-1 as runtime dependencies
  for Plasma 5 (the program does own binding with dlsym())
* Mon Sep  7 2015 glin@suse.com
- Add libappindicator3-devel to BuildRequires to enable appindicator
  support for Plasma 5
* Wed May 27 2015 ramaxlo@gmail.com
- Add qt5 immodule support.
- Add qt5gui-header-path-fix.patch to fix build failure.
- Add plasma5-dirty-fix.patch to fix plasma 5 black screen issue
  during starting. The reason is unknown so far.
  Refer to http://hyperrate.com/thread.php?tid=31194 for more
  information.
* Sun Mar  8 2015 i@marguerite.su
- add baselibs.conf as source
* Sat Mar  7 2015 i@marguerite.su
- update version 2.8.3
  * read http://hyperrate.com/gcin-source/Changelog.html
* Wed May 14 2014 glin@suse.com
- Update to 2.8.2
  + Make the pre-select phrases more precise
  + The tray icon now can show the status of CAPLOCK
- refresh patches
  + icon_path.diff
  + doc_dir.diff
  + gcin-keep-debug-symbols.patch
- drop gcin-bnc858193-fixes-frozen-gnome-shell.patch since upstream
  fixed the bug
* Mon Jan 13 2014 glin@suse.com
- Add gcin-bnc858193-fixes-frozen-gnome-shell.patch to fix the
  deadlock between gnome-shell (bnc#858193)
- Add gcin-keep-debug-symbols.patch to keep the debug symbols
- Add gcin-parallel-compiling.patch to fix the Makefile dependency
  for parallel compiling
* Wed Nov 27 2013 swyear@gmail.com
- add doc_dir.diff patch to fix doc path
  this path is used to open doc from gcin-tools
* Sun Nov 24 2013 swyear@gmail.com
- modify baselibs.conf
* Sat Nov 23 2013 swyear@gmail.com
- fix gcin can't on_the_spot, because libreoffice-gnome's lib name changed
  remove the test to force OOO_FORCE_DESKTOP=gnome
* Mon Nov 18 2013 swyear@gmail.com
- test remove gtk2(3) scriptlets in spec file, use macro (same as fcitx)
  instead
* Thu Oct  3 2013 i@marguerite.su
- remove gcin_scripts_modify-XIM_103.diff
  * qt3 is long dead, just drop scripts/modify-XIM which was also
    targeting for Mandriva/Fedora
- split gcin-gtk2-immodule, it's better
- fix xim.d-gcin
  * can't input in firefox/chrome, have to export GTK3_IM_MODULE
  * /usr/bin is already in $PATH. no /usr/X11R6/bin at all.
  * remove skim part, as it's dropped from openSUSE, newer scim
    don't need skim to support kde4/kde3.
  * remove the useless LC_TYPE test, we're installed, we just keep
    every locale work, so just export'em.
- add patch: gcin-2.8.1-gtk_immodules_path.patch
  * fix gtk2/3 immodule install path
* Fri Jul 26 2013 glin@suse.com
- Update to 2.8.1
  + Fix crash caused by keypad keys when there are words in the
    editing area.
  + Fix a file name issue when exporting the thesaurus
  + Clear unfinished changjie codes after switching to English mode
  + Support new input method: Array 10 keys
- Refresh icon_path.diff
  + Although gcin icon is installed to hicolor/64x64 by default,
    the icon size is actually 64x51, not suitable for a fixed-size
    dir.
* Wed Jul 17 2013 coolo@suse.com
- remove qt3 support, long dead
* Fri Feb 22 2013 swyear@gmail.com
- remove patch configure146p12.diff, use --doc_version_dir=N instead
* Fri Feb 22 2013 swyear@gmail.com
- Update to 2.8.0
- fix gtk_show_uri in Ubuntu, gcin will now open uri with gcin's own
  script
- fix pop-up status position
- Tray/OSD icon of Capslock status
- more bug fix and new features
* Sun Jan 20 2013 swyear@gmail.com
- Add libreoffice-gnome dependency as Recommends,
  so you will not install the whole office suite for gcin.
- Remove Requires gcin-anthy-module,
  most of the user don't need to input Japanese characters.
- modify xim.d-gcin to test if libreoffice-gnome was installed
- add a section about libreoffice-kde4's problem and workaround
  in gcin-README.suse
* Fri Jan 18 2013 swyear@gmail.com
- test remove libreoffice-gnome dependency
* Fri Dec  7 2012 meissner@suse.com
- readd a new gcin-libdir.patch as the bug was fixed only for
  strange subforms of x86_64 and not all other platforms.
* Thu Nov  8 2012 swyear@gmail.com
-remove gcin-libdir.patch, upstream had solved the bug
* Wed Nov  7 2012 swyear@gmail.com
- update to 2.7.9
- fix problem about switch to tsin from systray
- add %%flag_keypad_input_key to .cin files
- fix problem about Ctrl+Shift+* in firefox
- use gtk2 UI as default
- add vietnamese and german input method support
- remove chewing support temporary, need more develpment
- screen keyboard will keep on the top of all applications
- other minor bugs fixed
* Fri Oct  5 2012 dvaleev@suse.com
- Better detect for architecture specific libdir
* Mon Jun  4 2012 i@marguerite.su
- update bzip as source compression format.
  * sles can't recognize xz.
* Sat May 12 2012 i@marguerite.su
- bring in gcin as default IM for TW/HK/MO locale.
- add Provides: locale(zh_TW;zh_HK;zh_MO).
* Mon Apr  2 2012 glin@suse.com
- Amend the post-install script of gcin-gtk3-immodule to avoid
  adding gcin into gnome-shell more than once.
* Fri Mar 16 2012 swyear@gmail.com
- qt*-immodule subpackages are license GPL-2.0
* Tue Mar  6 2012 swyear@gmail.com
- Fix gcin-gtk3-immodule postin scriptlet for gnome3 panel
- Add new icons in gcin-branding-openSUSE package
* Sun Mar  4 2012 swyear@gmail.com
- Update to 2.7.5
- Fix blink when select words with arrow
- gen-deb from Yao Wei
- Fix crash when use number to select pre-select words
- Modify gtk3 postinst about gnome3 panel icon display
* Wed Feb  1 2012 glin@suse.com
- Follow the gtk2.spec and gtk3.spec to update the immodule cache
* Wed Feb  1 2012 swyear@gmail.com
- Remove some un-needed patchs
- Add Requires chewing-module and anthy-module
* Wed Jan  4 2012 swyear@gmail.com
- Update to 2.7.0
- Fix crash when switch to latin letter input
- Fix about can't input when launch QT application from KDE menu
* Wed Jan  4 2012 swyear@gmail.com
- Rollback to 2.6.6
* Thu Dec 29 2011 swyear@gmail.com
- Rollback to 2.6.7
* Wed Dec 28 2011 swyear@gmail.com
- Update to 2.6.8
- Open symbol table from tray icon
- Fix compile error
* Fri Dec 23 2011 swyear@gmail.com
- Update to 2.6.6
- Fix issues in pchome and facebook
* Fri Dec 23 2011 swyear@gmail.com
- remove qt4-moc-tmp.diff
- add lib64-qt4-moc.diff
* Fri Dec 23 2011 swyear@gmail.com
- add qt4-moc-tmp.diff to solve 64-bit compile issue
* Tue Dec 20 2011 swyear@gmail.com
- Update to 2.6.5
* Sun Dec 18 2011 swyear@gmail.com
- Update to 2.6.2
* Thu Dec 15 2011 swyear@gmail.com
- Update to 2.5.4
- Fix font-size change problem
* Tue Dec 13 2011 swyear@gmail.com
- Update to 2.5.3
- modify utf8-edit.diff, remove beaver (can't input chinese)
- gtab window patch from Tetralet
- gtk3 button css from caleb
- and more bugs fixed
* Thu Dec  1 2011 swyear@gmail.com
- Update to 2.3.0
- Add utf8-edit.diff, to use kwrite (KDE) or beaver (LXDE) to edit
  symbol table
* Sun Nov 20 2011 swyear@gmail.com
- Update to 2.0.1
- Use bold font as default
- Rename gcin-setup to gcin-tools
* Wed Nov 16 2011 swyear@gmail.com
- Update to 1.7.1.pre12
- Fix bug: crash when use Ctrl-Shift to switch to chewing and others
* Mon Oct 17 2011 swyear@gmail.com
- Update to gcin 1.7.0
- Fix bug: crash when click full/half trayicon (compile with gcc 4.4.3 -O)
* Sun Oct 16 2011 swyear@gmail.com
- Update to gcin 1.6.9 upstream release
* Thu Oct 13 2011 swyear@gmail.com
- Update to gcin 1.6.9.pre9
- fix qt-base program's problem, and other
- codes in gtk3-im were links to gtk-im, so rediff gcin-gtk3-im.diff(some fixed upstream)
- add GTK3_IM_MODULE=gcin in xim.d/gcin
* Tue Sep 20 2011 glin@suse.com
- Update to gcin 1.6.8
- Re-package the tarball as .tar.bz2 to be compatible with SLE11
- Add gcin-gtk3-im.diff to fix an error in gtk3-im module
- Add gcin-util-return.patch to return strings for errno
* Mon Jun 27 2011 swyear@gmail.com
- gcin 1.6.4 pre 24 can't build, Update to pre 25
* Fri Jun 24 2011 swyear@gmail.com
- Update to gcin 1.6.4 pre 24
* Mon Jun 13 2011 swyear@gmail.com
-Update README file
* Sat Jun 11 2011 swyear@gmail.com
-Update to gcin 1.6.4 pre 23
